import asyncio
import json
import unittest
from typing import Dict

from fxsdk.client.http import HttpRpcClient, AsyncHttpRpcClient
from fxsdk.client.websockets import WebsocketRpcClient
from fxsdk.msg import event

rpc_url = "http://127.0.0.1:26657"
rpc_client = HttpRpcClient(rpc_url)


class TestHttpRpcClient(unittest.TestCase):

    def test_get_block_result(self):
        block_res = rpc_client.get_block_results(1)
        print(block_res)
        assert block_res

    def test_get_block(self):
        block = rpc_client.get_block()
        print(json.dumps(block, indent=2))
        assert block

    def test_avg_block_time_interval(self):
        res = rpc_client.avg_block_time_interval()
        print(res)
        assert res


class TestWebsocketRpcClient(unittest.IsolatedAsyncioTestCase):

    @staticmethod
    async def callback(msg: Dict):
        print("msg", json.dumps(msg))

    async def test_get_block_result(self):
        loop = asyncio.get_event_loop()
        ws_client = await WebsocketRpcClient.create(endpoint_url=rpc_url, loop=loop, callback=self.callback)
        await ws_client.get_status()
        await ws_client.subscribe(event.EVENT_NEW_BLOCK)
        await asyncio.sleep(5)
        ws_client.close()


class TestAsyncHttpRpcClient(unittest.IsolatedAsyncioTestCase):
    async def test_get_block_result(self):
        rcp_client = await AsyncHttpRpcClient.create(rpc_url)
        block_results = await rcp_client.get_block_results(1)
        print(block_results)


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/erc20/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from fxsdk.x.fx.erc20.v1 import erc20_pb2 as fx_dot_erc20_dot_v1_dot_erc20__pb2
from fxsdk.x.fx.erc20.v1 import genesis_pb2 as fx_dot_erc20_dot_v1_dot_genesis__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66x/erc20/v1/tx.proto\x12\x0b\x66x.erc20.v1\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x66x/erc20/v1/erc20.proto\x1a\x19\x66x/erc20/v1/genesis.proto\x1a\x14gogoproto/gogo.proto\"a\n\x0eMsgConvertCoin\x12-\n\x04\x63oin\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\x18\n\x16MsgConvertCoinResponse\"\x8d\x01\n\x0fMsgConvertERC20\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12\x0e\n\x06sender\x18\x04 \x01(\t\"\x19\n\x17MsgConvertERC20Response\"r\n\x0fMsgConvertDenom\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12-\n\x04\x63oin\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06target\x18\x04 \x01(\t\"\x19\n\x17MsgConvertDenomResponse\"y\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x06params\x18\x02 \x01(\x0b\x32\x13.fx.erc20.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"\x85\x01\n\x0fMsgRegisterCoin\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"E\n\x17MsgRegisterCoinResponse\x12*\n\x04pair\x18\x01 \x01(\x0b\x32\x16.fx.erc20.v1.TokenPairB\x04\xc8\xde\x1f\x00\"v\n\x10MsgRegisterERC20\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x14\n\x0c\x65rc20address\x18\x02 \x01(\t\x12\x0f\n\x07\x61liases\x18\x03 \x03(\t:\x0e\x82\xe7\xb0*\tauthority\"F\n\x18MsgRegisterERC20Response\x12*\n\x04pair\x18\x01 \x01(\x0b\x32\x16.fx.erc20.v1.TokenPairB\x04\xc8\xde\x1f\x00\"f\n\x18MsgToggleTokenConversion\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05token\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"N\n MsgToggleTokenConversionResponse\x12*\n\x04pair\x18\x01 \x01(\x0b\x32\x16.fx.erc20.v1.TokenPairB\x04\xc8\xde\x1f\x00\"p\n\x13MsgUpdateDenomAlias\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"\x1d\n\x1bMsgUpdateDenomAliasResponse2\xcc\x05\n\x03Msg\x12O\n\x0b\x43onvertCoin\x12\x1b.fx.erc20.v1.MsgConvertCoin\x1a#.fx.erc20.v1.MsgConvertCoinResponse\x12R\n\x0c\x43onvertERC20\x12\x1c.fx.erc20.v1.MsgConvertERC20\x1a$.fx.erc20.v1.MsgConvertERC20Response\x12R\n\x0c\x43onvertDenom\x12\x1c.fx.erc20.v1.MsgConvertDenom\x1a$.fx.erc20.v1.MsgConvertDenomResponse\x12R\n\x0cUpdateParams\x12\x1c.fx.erc20.v1.MsgUpdateParams\x1a$.fx.erc20.v1.MsgUpdateParamsResponse\x12R\n\x0cRegisterCoin\x12\x1c.fx.erc20.v1.MsgRegisterCoin\x1a$.fx.erc20.v1.MsgRegisterCoinResponse\x12U\n\rRegisterERC20\x12\x1d.fx.erc20.v1.MsgRegisterERC20\x1a%.fx.erc20.v1.MsgRegisterERC20Response\x12m\n\x15ToggleTokenConversion\x12%.fx.erc20.v1.MsgToggleTokenConversion\x1a-.fx.erc20.v1.MsgToggleTokenConversionResponse\x12^\n\x10UpdateDenomAlias\x12 .fx.erc20.v1.MsgUpdateDenomAlias\x1a(.fx.erc20.v1.MsgUpdateDenomAliasResponseB,Z*github.com/functionx/fx-core/x/erc20/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.erc20.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/functionx/fx-core/x/erc20/types'
  _MSGCONVERTCOIN.fields_by_name['coin']._options = None
  _MSGCONVERTCOIN.fields_by_name['coin']._serialized_options = b'\310\336\037\000'
  _MSGCONVERTERC20.fields_by_name['amount']._options = None
  _MSGCONVERTERC20.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGCONVERTDENOM.fields_by_name['coin']._options = None
  _MSGCONVERTDENOM.fields_by_name['coin']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSGREGISTERCOIN.fields_by_name['authority']._options = None
  _MSGREGISTERCOIN.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGREGISTERCOIN.fields_by_name['metadata']._options = None
  _MSGREGISTERCOIN.fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _MSGREGISTERCOIN._options = None
  _MSGREGISTERCOIN._serialized_options = b'\202\347\260*\tauthority'
  _MSGREGISTERCOINRESPONSE.fields_by_name['pair']._options = None
  _MSGREGISTERCOINRESPONSE.fields_by_name['pair']._serialized_options = b'\310\336\037\000'
  _MSGREGISTERERC20.fields_by_name['authority']._options = None
  _MSGREGISTERERC20.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGREGISTERERC20._options = None
  _MSGREGISTERERC20._serialized_options = b'\202\347\260*\tauthority'
  _MSGREGISTERERC20RESPONSE.fields_by_name['pair']._options = None
  _MSGREGISTERERC20RESPONSE.fields_by_name['pair']._serialized_options = b'\310\336\037\000'
  _MSGTOGGLETOKENCONVERSION.fields_by_name['authority']._options = None
  _MSGTOGGLETOKENCONVERSION.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGTOGGLETOKENCONVERSION._options = None
  _MSGTOGGLETOKENCONVERSION._serialized_options = b'\202\347\260*\tauthority'
  _MSGTOGGLETOKENCONVERSIONRESPONSE.fields_by_name['pair']._options = None
  _MSGTOGGLETOKENCONVERSIONRESPONSE.fields_by_name['pair']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEDENOMALIAS.fields_by_name['authority']._options = None
  _MSGUPDATEDENOMALIAS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEDENOMALIAS._options = None
  _MSGUPDATEDENOMALIAS._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGCONVERTCOIN']._serialized_start=227
  _globals['_MSGCONVERTCOIN']._serialized_end=324
  _globals['_MSGCONVERTCOINRESPONSE']._serialized_start=326
  _globals['_MSGCONVERTCOINRESPONSE']._serialized_end=350
  _globals['_MSGCONVERTERC20']._serialized_start=353
  _globals['_MSGCONVERTERC20']._serialized_end=494
  _globals['_MSGCONVERTERC20RESPONSE']._serialized_start=496
  _globals['_MSGCONVERTERC20RESPONSE']._serialized_end=521
  _globals['_MSGCONVERTDENOM']._serialized_start=523
  _globals['_MSGCONVERTDENOM']._serialized_end=637
  _globals['_MSGCONVERTDENOMRESPONSE']._serialized_start=639
  _globals['_MSGCONVERTDENOMRESPONSE']._serialized_end=664
  _globals['_MSGUPDATEPARAMS']._serialized_start=666
  _globals['_MSGUPDATEPARAMS']._serialized_end=787
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=789
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=814
  _globals['_MSGREGISTERCOIN']._serialized_start=817
  _globals['_MSGREGISTERCOIN']._serialized_end=950
  _globals['_MSGREGISTERCOINRESPONSE']._serialized_start=952
  _globals['_MSGREGISTERCOINRESPONSE']._serialized_end=1021
  _globals['_MSGREGISTERERC20']._serialized_start=1023
  _globals['_MSGREGISTERERC20']._serialized_end=1141
  _globals['_MSGREGISTERERC20RESPONSE']._serialized_start=1143
  _globals['_MSGREGISTERERC20RESPONSE']._serialized_end=1213
  _globals['_MSGTOGGLETOKENCONVERSION']._serialized_start=1215
  _globals['_MSGTOGGLETOKENCONVERSION']._serialized_end=1317
  _globals['_MSGTOGGLETOKENCONVERSIONRESPONSE']._serialized_start=1319
  _globals['_MSGTOGGLETOKENCONVERSIONRESPONSE']._serialized_end=1397
  _globals['_MSGUPDATEDENOMALIAS']._serialized_start=1399
  _globals['_MSGUPDATEDENOMALIAS']._serialized_end=1511
  _globals['_MSGUPDATEDENOMALIASRESPONSE']._serialized_start=1513
  _globals['_MSGUPDATEDENOMALIASRESPONSE']._serialized_end=1542
  _globals['_MSG']._serialized_start=1545
  _globals['_MSG']._serialized_end=2261
# @@protoc_insertion_point(module_scope)



from datetime import datetime
from decimal import Decimal
from typing import NamedTuple

from fxsdk.coin import parse_coin
from fxsdk.dec import dec_from_str
from fxsdk.wallet.address import Address
from fxsdk.x.fx.dex.v1.funding_pb2 import PairFundingRate as PairFundingRateProto
from fxsdk.x.fx.dex.v1.order_pb2 import Order as OrderProto
from fxsdk.x.fx.dex.v1.position_pb2 import Position as PositionProto
from fxsdk.x.fx.dex.v1.match_pb2 import OrderDepth as OrderDepthProto


class Position(NamedTuple):
    id: int
    owner: str
    pair_id: str
    direction: str
    entry_price: Decimal
    mark_price: Decimal
    liquidation_price: Decimal
    base_quantity: Decimal
    margin: Decimal
    leverage: int
    unrealized_pnl: Decimal
    margin_rate: Decimal
    initial_margin: Decimal
    pending_order_quantity: Decimal


def new_position_from_proto(position: PositionProto, prefix: str = 'mx') -> Position:
    direction = ""
    if str(position.direction) == '1':
        direction = "long"
    elif str(position.direction) == '2':
        direction = "short"
    return Position(
        int(position.id),
        Address(position.owner, prefix).to_string(),
        position.pair_id,
        direction,
        dec_from_str(position.entry_price),
        dec_from_str(position.mark_price),
        dec_from_str(position.liquidation_price),
        dec_from_str(position.base_quantity),
        dec_from_str(position.margin),
        position.leverage,
        dec_from_str(position.unrealized_pnl),
        dec_from_str(position.margin_rate),
        dec_from_str(position.initial_margin),
        dec_from_str(position.pending_order_quantity)
    )


class Order(NamedTuple):
    id: str
    owner: str
    pair_id: str
    direction: str
    price: Decimal
    base_quantity: Decimal
    quote_quantity: Decimal
    filled_quantity: Decimal
    filled_avg_price: Decimal
    leverage: int
    status: str
    order_type: str
    cost_fee: Decimal
    locked_fee: Decimal
    fee_denom: str


def new_order_from_proto(order: OrderProto, prefix: str = 'mx') -> Order:
    cost_fee_coin = parse_coin(order.cost_fee)
    locked_fee_coin = parse_coin(order.locked_fee)
    fee_denom = cost_fee_coin.denom
    if cost_fee_coin.denom == '':
        fee_denom = locked_fee_coin.denom
    return Order(
        order.id,
        Address(order.owner, prefix).to_string(),
        order.pair_id,
        str(order.direction),
        dec_from_str(order.price),
        dec_from_str(order.base_quantity),
        dec_from_str(order.quote_quantity),
        dec_from_str(order.filled_quantity),
        dec_from_str(order.filled_avg_price),
        order.leverage,
        str(order.status),
        str(order.order_type),
        dec_from_str(cost_fee_coin.amount),
        dec_from_str(locked_fee_coin.amount),
        fee_denom,
    )


class PairFundingRate(NamedTuple):
    pair_id: str
    funding_rate: Decimal
    funding_time: datetime


def new_pair_funding_rate_from_proto(pair_funding_rate: PairFundingRateProto) -> PairFundingRate:
    return PairFundingRate(
        pair_funding_rate.pair_id,
        dec_from_str(pair_funding_rate.funding_rate),
        datetime.fromtimestamp(pair_funding_rate.funding_time)
    )


class OrderDepth(NamedTuple):
    price: Decimal
    quantity: Decimal


def new_order_depth_from_proto(order_depth: OrderDepthProto) -> OrderDepth:
    return OrderDepth(
        dec_from_str(order_depth.price),
        dec_from_str(order_depth.quantity),
    )


class OrderDepths(NamedTuple):
    asks: [OrderDepth]
    bids: [OrderDepth]


def new_order_depths_from_proto(asks: [OrderDepthProto], bids: [OrderDepthProto]) -> OrderDepths:
    return OrderDepths(
        [new_order_depth_from_proto(ask) for ask in asks],
        [new_order_depth_from_proto(bid) for bid in bids],
    )


class PairPrice(NamedTuple):
    pair_id: str
    price: Decimal


class DecCoin(NamedTuple):
    denom: str
    amount: Decimal



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/position.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x66x/dex/v1/position.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\">\n\x08StoreDec\x12\x32\n\x05value\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"F\n\x11TotalPositionSize\x12\x31\n\x04size\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"8\n\nPositionID\x12*\n\x02id\x18\x01 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\"@\n\x0bPositionIDs\x12\x31\n\x0cposition_ids\x18\x01 \x03(\x0b\x32\x15.fx.dex.v1.PositionIDB\x04\xc8\xde\x1f\x00\"\xe4\x05\n\x08Position\x12*\n\x02id\x18\x01 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12@\n\x05owner\x18\x02 \x01(\x0c\x42\x31\xfa\xde\x1f-github.com/cosmos/cosmos-sdk/types.AccAddress\x12\x0f\n\x07pair_id\x18\x03 \x01(\t\x12*\n\tdirection\x18\x04 \x01(\x0e\x32\x17.fx.dex.v1.PosDirection\x12\x38\n\x0b\x65ntry_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x37\n\nmark_price\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12>\n\x11liquidation_price\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12:\n\rbase_quantity\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x33\n\x06margin\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x10\n\x08leverage\x18\n \x01(\x03\x12;\n\x0eunrealized_pnl\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x38\n\x0bmargin_rate\x18\x0c \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12;\n\x0einitial_margin\x18\r \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x43\n\x16pending_order_quantity\x18\x0e \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"9\n\tPositions\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x13.fx.dex.v1.PositionB\x04\xc8\xde\x1f\x00*f\n\x0cPosDirection\x12\"\n\x0cPOSITIONBOTH\x10\x00\x1a\x10\x8a\x9d \x0cPOSITIONBOTH\x12\x12\n\x04LONG\x10\x01\x1a\x08\x8a\x9d \x04LONG\x12\x14\n\x05SHORT\x10\x02\x1a\t\x8a\x9d \x05SHORT\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.position_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _POSDIRECTION._options = None
  _POSDIRECTION._serialized_options = b'\210\243\036\000\250\244\036\001'
  _POSDIRECTION.values_by_name["POSITIONBOTH"]._options = None
  _POSDIRECTION.values_by_name["POSITIONBOTH"]._serialized_options = b'\212\235 \014POSITIONBOTH'
  _POSDIRECTION.values_by_name["LONG"]._options = None
  _POSDIRECTION.values_by_name["LONG"]._serialized_options = b'\212\235 \004LONG'
  _POSDIRECTION.values_by_name["SHORT"]._options = None
  _POSDIRECTION.values_by_name["SHORT"]._serialized_options = b'\212\235 \005SHORT'
  _STOREDEC.fields_by_name['value']._options = None
  _STOREDEC.fields_by_name['value']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _TOTALPOSITIONSIZE.fields_by_name['size']._options = None
  _TOTALPOSITIONSIZE.fields_by_name['size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITIONID.fields_by_name['id']._options = None
  _POSITIONID.fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _POSITIONIDS.fields_by_name['position_ids']._options = None
  _POSITIONIDS.fields_by_name['position_ids']._serialized_options = b'\310\336\037\000'
  _POSITION.fields_by_name['id']._options = None
  _POSITION.fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _POSITION.fields_by_name['owner']._options = None
  _POSITION.fields_by_name['owner']._serialized_options = b'\372\336\037-github.com/cosmos/cosmos-sdk/types.AccAddress'
  _POSITION.fields_by_name['entry_price']._options = None
  _POSITION.fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['mark_price']._options = None
  _POSITION.fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['liquidation_price']._options = None
  _POSITION.fields_by_name['liquidation_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['base_quantity']._options = None
  _POSITION.fields_by_name['base_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['margin']._options = None
  _POSITION.fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['unrealized_pnl']._options = None
  _POSITION.fields_by_name['unrealized_pnl']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['margin_rate']._options = None
  _POSITION.fields_by_name['margin_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['initial_margin']._options = None
  _POSITION.fields_by_name['initial_margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['pending_order_quantity']._options = None
  _POSITION.fields_by_name['pending_order_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITIONS.fields_by_name['positions']._options = None
  _POSITIONS.fields_by_name['positions']._serialized_options = b'\310\336\037\000'
  _globals['_POSDIRECTION']._serialized_start=1123
  _globals['_POSDIRECTION']._serialized_end=1225
  _globals['_STOREDEC']._serialized_start=61
  _globals['_STOREDEC']._serialized_end=123
  _globals['_TOTALPOSITIONSIZE']._serialized_start=125
  _globals['_TOTALPOSITIONSIZE']._serialized_end=195
  _globals['_POSITIONID']._serialized_start=197
  _globals['_POSITIONID']._serialized_end=253
  _globals['_POSITIONIDS']._serialized_start=255
  _globals['_POSITIONIDS']._serialized_end=319
  _globals['_POSITION']._serialized_start=322
  _globals['_POSITION']._serialized_end=1062
  _globals['_POSITIONS']._serialized_start=1064
  _globals['_POSITIONS']._serialized_end=1121
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.erc20.v1 import query_pb2 as fx_dot_erc20_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TokenPairs = channel.unary_unary(
                '/fx.erc20.v1.Query/TokenPairs',
                request_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairsRequest.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairsResponse.FromString,
                )
        self.TokenPair = channel.unary_unary(
                '/fx.erc20.v1.Query/TokenPair',
                request_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairRequest.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairResponse.FromString,
                )
        self.Params = channel.unary_unary(
                '/fx.erc20.v1.Query/Params',
                request_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.DenomAliases = channel.unary_unary(
                '/fx.erc20.v1.Query/DenomAliases',
                request_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryDenomAliasesRequest.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryDenomAliasesResponse.FromString,
                )
        self.AliasDenom = channel.unary_unary(
                '/fx.erc20.v1.Query/AliasDenom',
                request_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryAliasDenomRequest.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryAliasDenomResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def TokenPairs(self, request, context):
        """Retrieves registered token pairs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TokenPair(self, request, context):
        """Retrieves a registered token pair
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params retrieves the erc20 module params
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomAliases(self, request, context):
        """Retrieves registered denom aliases
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AliasDenom(self, request, context):
        """Retrieves registered alias denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TokenPairs': grpc.unary_unary_rpc_method_handler(
                    servicer.TokenPairs,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairsRequest.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairsResponse.SerializeToString,
            ),
            'TokenPair': grpc.unary_unary_rpc_method_handler(
                    servicer.TokenPair,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairRequest.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'DenomAliases': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomAliases,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryDenomAliasesRequest.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryDenomAliasesResponse.SerializeToString,
            ),
            'AliasDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.AliasDenom,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryAliasDenomRequest.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_query__pb2.QueryAliasDenomResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.erc20.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def TokenPairs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Query/TokenPairs',
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairsRequest.SerializeToString,
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TokenPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Query/TokenPair',
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairRequest.SerializeToString,
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryTokenPairResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Query/Params',
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomAliases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Query/DenomAliases',
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryDenomAliasesRequest.SerializeToString,
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryDenomAliasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AliasDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Query/AliasDenom',
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryAliasDenomRequest.SerializeToString,
            fx_dot_erc20_dot_v1_dot_query__pb2.QueryAliasDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.evm.v1 import tx_pb2 as fx_dot_evm_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the x/evm Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CallContract = channel.unary_unary(
                '/fx.evm.v1.Msg/CallContract',
                request_serializer=fx_dot_evm_dot_v1_dot_tx__pb2.MsgCallContract.SerializeToString,
                response_deserializer=fx_dot_evm_dot_v1_dot_tx__pb2.MsgCallContractResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the x/evm Msg service.
    """

    def CallContract(self, request, context):
        """CallContract defines a (governance) operation for updating the x/evm module
        callContract. The authority defaults to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CallContract': grpc.unary_unary_rpc_method_handler(
                    servicer.CallContract,
                    request_deserializer=fx_dot_evm_dot_v1_dot_tx__pb2.MsgCallContract.FromString,
                    response_serializer=fx_dot_evm_dot_v1_dot_tx__pb2.MsgCallContractResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.evm.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the x/evm Msg service.
    """

    @staticmethod
    def CallContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.evm.v1.Msg/CallContract',
            fx_dot_evm_dot_v1_dot_tx__pb2.MsgCallContract.SerializeToString,
            fx_dot_evm_dot_v1_dot_tx__pb2.MsgCallContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.dex.v1 import tx_pb2 as fx_dot_dex_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrder = channel.unary_unary(
                '/fx.dex.v1.Msg/CreateOrder',
                request_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCreateOrder.SerializeToString,
                response_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCreateOrderResponse.FromString,
                )
        self.CancelOrder = channel.unary_unary(
                '/fx.dex.v1.Msg/CancelOrder',
                request_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCancelOrder.SerializeToString,
                response_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCancelOrderResponse.FromString,
                )
        self.AddMargin = channel.unary_unary(
                '/fx.dex.v1.Msg/AddMargin',
                request_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgAddMargin.SerializeToString,
                response_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgAddMarginResp.FromString,
                )
        self.ClosePosition = channel.unary_unary(
                '/fx.dex.v1.Msg/ClosePosition',
                request_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgClosePosition.SerializeToString,
                response_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgClosePositionResp.FromString,
                )
        self.LiquidationPosition = channel.unary_unary(
                '/fx.dex.v1.Msg/LiquidationPosition',
                request_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgLiquidationPosition.SerializeToString,
                response_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgLiquidationPositionResp.FromString,
                )
        self.FundDexPool = channel.unary_unary(
                '/fx.dex.v1.Msg/FundDexPool',
                request_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgFundDexPool.SerializeToString,
                response_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgFundDexPoolResp.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddMargin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClosePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiquidationPosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FundDexPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrder,
                    request_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCreateOrder.FromString,
                    response_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCreateOrderResponse.SerializeToString,
            ),
            'CancelOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelOrder,
                    request_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCancelOrder.FromString,
                    response_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgCancelOrderResponse.SerializeToString,
            ),
            'AddMargin': grpc.unary_unary_rpc_method_handler(
                    servicer.AddMargin,
                    request_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgAddMargin.FromString,
                    response_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgAddMarginResp.SerializeToString,
            ),
            'ClosePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.ClosePosition,
                    request_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgClosePosition.FromString,
                    response_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgClosePositionResp.SerializeToString,
            ),
            'LiquidationPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.LiquidationPosition,
                    request_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgLiquidationPosition.FromString,
                    response_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgLiquidationPositionResp.SerializeToString,
            ),
            'FundDexPool': grpc.unary_unary_rpc_method_handler(
                    servicer.FundDexPool,
                    request_deserializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgFundDexPool.FromString,
                    response_serializer=fx_dot_dex_dot_v1_dot_tx__pb2.MsgFundDexPoolResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.dex.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.dex.v1.Msg/CreateOrder',
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgCreateOrder.SerializeToString,
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgCreateOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.dex.v1.Msg/CancelOrder',
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgCancelOrder.SerializeToString,
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgCancelOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddMargin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.dex.v1.Msg/AddMargin',
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgAddMargin.SerializeToString,
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgAddMarginResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClosePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.dex.v1.Msg/ClosePosition',
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgClosePosition.SerializeToString,
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgClosePositionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LiquidationPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.dex.v1.Msg/LiquidationPosition',
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgLiquidationPosition.SerializeToString,
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgLiquidationPositionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FundDexPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.dex.v1.Msg/FundDexPool',
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgFundDexPool.SerializeToString,
            fx_dot_dex_dot_v1_dot_tx__pb2.MsgFundDexPoolResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.erc20.v1 import tx_pb2 as fx_dot_erc20_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the erc20 Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConvertCoin = channel.unary_unary(
                '/fx.erc20.v1.Msg/ConvertCoin',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertCoin.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertCoinResponse.FromString,
                )
        self.ConvertERC20 = channel.unary_unary(
                '/fx.erc20.v1.Msg/ConvertERC20',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertERC20.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertERC20Response.FromString,
                )
        self.ConvertDenom = channel.unary_unary(
                '/fx.erc20.v1.Msg/ConvertDenom',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertDenom.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertDenomResponse.FromString,
                )
        self.UpdateParams = channel.unary_unary(
                '/fx.erc20.v1.Msg/UpdateParams',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                )
        self.RegisterCoin = channel.unary_unary(
                '/fx.erc20.v1.Msg/RegisterCoin',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterCoin.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterCoinResponse.FromString,
                )
        self.RegisterERC20 = channel.unary_unary(
                '/fx.erc20.v1.Msg/RegisterERC20',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterERC20.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterERC20Response.FromString,
                )
        self.ToggleTokenConversion = channel.unary_unary(
                '/fx.erc20.v1.Msg/ToggleTokenConversion',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgToggleTokenConversion.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgToggleTokenConversionResponse.FromString,
                )
        self.UpdateDenomAlias = channel.unary_unary(
                '/fx.erc20.v1.Msg/UpdateDenomAlias',
                request_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateDenomAlias.SerializeToString,
                response_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateDenomAliasResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the erc20 Msg service.
    """

    def ConvertCoin(self, request, context):
        """ConvertCoin mints a ERC20 representation of the SDK Coin denom that is
        registered on the token mapping.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConvertERC20(self, request, context):
        """ConvertERC20 mints a Cosmos coin representation of the ERC20 token contract
        that is registered on the token mapping.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConvertDenom(self, request, context):
        """ConvertDenom convert denom to other denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/erc20 module
        parameters. The authority is hard-coded to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterCoin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterERC20(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ToggleTokenConversion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDenomAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConvertCoin': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertCoin,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertCoin.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertCoinResponse.SerializeToString,
            ),
            'ConvertERC20': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertERC20,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertERC20.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertERC20Response.SerializeToString,
            ),
            'ConvertDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertDenom,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertDenom.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertDenomResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'RegisterCoin': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterCoin,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterCoin.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterCoinResponse.SerializeToString,
            ),
            'RegisterERC20': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterERC20,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterERC20.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterERC20Response.SerializeToString,
            ),
            'ToggleTokenConversion': grpc.unary_unary_rpc_method_handler(
                    servicer.ToggleTokenConversion,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgToggleTokenConversion.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgToggleTokenConversionResponse.SerializeToString,
            ),
            'UpdateDenomAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDenomAlias,
                    request_deserializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateDenomAlias.FromString,
                    response_serializer=fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateDenomAliasResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.erc20.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the erc20 Msg service.
    """

    @staticmethod
    def ConvertCoin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/ConvertCoin',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertCoin.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertCoinResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConvertERC20(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/ConvertERC20',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertERC20.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertERC20Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConvertDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/ConvertDenom',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertDenom.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgConvertDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/UpdateParams',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterCoin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/RegisterCoin',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterCoin.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterCoinResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterERC20(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/RegisterERC20',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterERC20.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgRegisterERC20Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ToggleTokenConversion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/ToggleTokenConversion',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgToggleTokenConversion.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgToggleTokenConversionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDenomAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.erc20.v1.Msg/UpdateDenomAlias',
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateDenomAlias.SerializeToString,
            fx_dot_erc20_dot_v1_dot_tx__pb2.MsgUpdateDenomAliasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/evm/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from fxsdk.x.ethermint.evm.v1 import evm_pb2 as ethermint_dot_evm_dot_v1_dot_evm__pb2
from fxsdk.x.ethermint.evm.v1 import tx_pb2 as ethermint_dot_evm_dot_v1_dot_tx__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65thermint/evm/v1/query.proto\x12\x10\x65thermint.evm.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1a\x65thermint/evm/v1/evm.proto\x1a\x19\x65thermint/evm/v1/tx.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"0\n\x13QueryAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"I\n\x14QueryAccountResponse\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\t\x12\x11\n\tcode_hash\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\x04\"6\n\x19QueryCosmosAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"^\n\x1aQueryCosmosAccountResponse\x12\x16\n\x0e\x63osmos_address\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04\">\n\x1cQueryValidatorAccountRequest\x12\x14\n\x0c\x63ons_address\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"b\n\x1dQueryValidatorAccountResponse\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x04\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04\"0\n\x13QueryBalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\'\n\x14QueryBalanceResponse\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\t\"=\n\x13QueryStorageRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"%\n\x14QueryStorageResponse\x12\r\n\x05value\x18\x01 \x01(\t\"-\n\x10QueryCodeRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"!\n\x11QueryCodeResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x0c\"h\n\x12QueryTxLogsRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"w\n\x13QueryTxLogsResponse\x12#\n\x04logs\x18\x01 \x03(\x0b\x32\x15.ethermint.evm.v1.Log\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x14\n\x12QueryParamsRequest\"E\n\x13QueryParamsResponse\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.ethermint.evm.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x8f\x01\n\x0e\x45thCallRequest\x12\x0c\n\x04\x61rgs\x18\x01 \x01(\x0c\x12\x0f\n\x07gas_cap\x18\x02 \x01(\x04\x12L\n\x10proposer_address\x18\x03 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddress\x12\x10\n\x08\x63hain_id\x18\x04 \x01(\x03\"\"\n\x13\x45stimateGasResponse\x12\x0b\n\x03gas\x18\x01 \x01(\x04\"\x83\x03\n\x13QueryTraceTxRequest\x12,\n\x03msg\x18\x01 \x01(\x0b\x32\x1f.ethermint.evm.v1.MsgEthereumTx\x12\x33\n\x0ctrace_config\x18\x03 \x01(\x0b\x32\x1d.ethermint.evm.v1.TraceConfig\x12\x35\n\x0cpredecessors\x18\x04 \x03(\x0b\x32\x1f.ethermint.evm.v1.MsgEthereumTx\x12\x14\n\x0c\x62lock_number\x18\x05 \x01(\x03\x12\x12\n\nblock_hash\x18\x06 \x01(\t\x12\x38\n\nblock_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12L\n\x10proposer_address\x18\x08 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddress\x12\x10\n\x08\x63hain_id\x18\t \x01(\x03J\x04\x08\x02\x10\x03R\x08tx_index\"$\n\x14QueryTraceTxResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\xbf\x02\n\x16QueryTraceBlockRequest\x12,\n\x03txs\x18\x01 \x03(\x0b\x32\x1f.ethermint.evm.v1.MsgEthereumTx\x12\x33\n\x0ctrace_config\x18\x03 \x01(\x0b\x32\x1d.ethermint.evm.v1.TraceConfig\x12\x14\n\x0c\x62lock_number\x18\x05 \x01(\x03\x12\x12\n\nblock_hash\x18\x06 \x01(\t\x12\x38\n\nblock_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12L\n\x10proposer_address\x18\x08 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddress\x12\x10\n\x08\x63hain_id\x18\t \x01(\x03\"\'\n\x17QueryTraceBlockResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x15\n\x13QueryBaseFeeRequest\"T\n\x14QueryBaseFeeResponse\x12<\n\x08\x62\x61se_fee\x18\x01 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int2\xef\x0c\n\x05Query\x12\x85\x01\n\x07\x41\x63\x63ount\x12%.ethermint.evm.v1.QueryAccountRequest\x1a&.ethermint.evm.v1.QueryAccountResponse\"+\x82\xd3\xe4\x93\x02%\x12#/ethermint/evm/v1/account/{address}\x12\x9e\x01\n\rCosmosAccount\x12+.ethermint.evm.v1.QueryCosmosAccountRequest\x1a,.ethermint.evm.v1.QueryCosmosAccountResponse\"2\x82\xd3\xe4\x93\x02,\x12*/ethermint/evm/v1/cosmos_account/{address}\x12\xaf\x01\n\x10ValidatorAccount\x12..ethermint.evm.v1.QueryValidatorAccountRequest\x1a/.ethermint.evm.v1.QueryValidatorAccountResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/ethermint/evm/v1/validator_account/{cons_address}\x12\x86\x01\n\x07\x42\x61lance\x12%.ethermint.evm.v1.QueryBalanceRequest\x1a&.ethermint.evm.v1.QueryBalanceResponse\",\x82\xd3\xe4\x93\x02&\x12$/ethermint/evm/v1/balances/{address}\x12\x8b\x01\n\x07Storage\x12%.ethermint.evm.v1.QueryStorageRequest\x1a&.ethermint.evm.v1.QueryStorageResponse\"1\x82\xd3\xe4\x93\x02+\x12)/ethermint/evm/v1/storage/{address}/{key}\x12z\n\x04\x43ode\x12\".ethermint.evm.v1.QueryCodeRequest\x1a#.ethermint.evm.v1.QueryCodeResponse\")\x82\xd3\xe4\x93\x02#\x12!/ethermint/evm/v1/codes/{address}\x12w\n\x06Params\x12$.ethermint.evm.v1.QueryParamsRequest\x1a%.ethermint.evm.v1.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/ethermint/evm/v1/params\x12x\n\x07\x45thCall\x12 .ethermint.evm.v1.EthCallRequest\x1a\'.ethermint.evm.v1.MsgEthereumTxResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/ethermint/evm/v1/eth_call\x12~\n\x0b\x45stimateGas\x12 .ethermint.evm.v1.EthCallRequest\x1a%.ethermint.evm.v1.EstimateGasResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/ethermint/evm/v1/estimate_gas\x12|\n\x07TraceTx\x12%.ethermint.evm.v1.QueryTraceTxRequest\x1a&.ethermint.evm.v1.QueryTraceTxResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/ethermint/evm/v1/trace_tx\x12\x88\x01\n\nTraceBlock\x12(.ethermint.evm.v1.QueryTraceBlockRequest\x1a).ethermint.evm.v1.QueryTraceBlockResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/ethermint/evm/v1/trace_block\x12|\n\x07\x42\x61seFee\x12%.ethermint.evm.v1.QueryBaseFeeRequest\x1a&.ethermint.evm.v1.QueryBaseFeeResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/ethermint/evm/v1/base_feeB(Z&github.com/evmos/ethermint/x/evm/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.evm.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/evmos/ethermint/x/evm/types'
  _QUERYACCOUNTREQUEST._options = None
  _QUERYACCOUNTREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYCOSMOSACCOUNTREQUEST._options = None
  _QUERYCOSMOSACCOUNTREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYVALIDATORACCOUNTREQUEST._options = None
  _QUERYVALIDATORACCOUNTREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYBALANCEREQUEST._options = None
  _QUERYBALANCEREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYSTORAGEREQUEST._options = None
  _QUERYSTORAGEREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYCODEREQUEST._options = None
  _QUERYCODEREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYTXLOGSREQUEST._options = None
  _QUERYTXLOGSREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _ETHCALLREQUEST.fields_by_name['proposer_address']._options = None
  _ETHCALLREQUEST.fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _QUERYTRACETXREQUEST.fields_by_name['block_time']._options = None
  _QUERYTRACETXREQUEST.fields_by_name['block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _QUERYTRACETXREQUEST.fields_by_name['proposer_address']._options = None
  _QUERYTRACETXREQUEST.fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _QUERYTRACEBLOCKREQUEST.fields_by_name['block_time']._options = None
  _QUERYTRACEBLOCKREQUEST.fields_by_name['block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _QUERYTRACEBLOCKREQUEST.fields_by_name['proposer_address']._options = None
  _QUERYTRACEBLOCKREQUEST.fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _QUERYBASEFEERESPONSE.fields_by_name['base_fee']._options = None
  _QUERYBASEFEERESPONSE.fields_by_name['base_fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _QUERY.methods_by_name['Account']._options = None
  _QUERY.methods_by_name['Account']._serialized_options = b'\202\323\344\223\002%\022#/ethermint/evm/v1/account/{address}'
  _QUERY.methods_by_name['CosmosAccount']._options = None
  _QUERY.methods_by_name['CosmosAccount']._serialized_options = b'\202\323\344\223\002,\022*/ethermint/evm/v1/cosmos_account/{address}'
  _QUERY.methods_by_name['ValidatorAccount']._options = None
  _QUERY.methods_by_name['ValidatorAccount']._serialized_options = b'\202\323\344\223\0024\0222/ethermint/evm/v1/validator_account/{cons_address}'
  _QUERY.methods_by_name['Balance']._options = None
  _QUERY.methods_by_name['Balance']._serialized_options = b'\202\323\344\223\002&\022$/ethermint/evm/v1/balances/{address}'
  _QUERY.methods_by_name['Storage']._options = None
  _QUERY.methods_by_name['Storage']._serialized_options = b'\202\323\344\223\002+\022)/ethermint/evm/v1/storage/{address}/{key}'
  _QUERY.methods_by_name['Code']._options = None
  _QUERY.methods_by_name['Code']._serialized_options = b'\202\323\344\223\002#\022!/ethermint/evm/v1/codes/{address}'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/ethermint/evm/v1/params'
  _QUERY.methods_by_name['EthCall']._options = None
  _QUERY.methods_by_name['EthCall']._serialized_options = b'\202\323\344\223\002\034\022\032/ethermint/evm/v1/eth_call'
  _QUERY.methods_by_name['EstimateGas']._options = None
  _QUERY.methods_by_name['EstimateGas']._serialized_options = b'\202\323\344\223\002 \022\036/ethermint/evm/v1/estimate_gas'
  _QUERY.methods_by_name['TraceTx']._options = None
  _QUERY.methods_by_name['TraceTx']._serialized_options = b'\202\323\344\223\002\034\022\032/ethermint/evm/v1/trace_tx'
  _QUERY.methods_by_name['TraceBlock']._options = None
  _QUERY.methods_by_name['TraceBlock']._serialized_options = b'\202\323\344\223\002\037\022\035/ethermint/evm/v1/trace_block'
  _QUERY.methods_by_name['BaseFee']._options = None
  _QUERY.methods_by_name['BaseFee']._serialized_options = b'\202\323\344\223\002\034\022\032/ethermint/evm/v1/base_fee'
  _globals['_QUERYACCOUNTREQUEST']._serialized_start=234
  _globals['_QUERYACCOUNTREQUEST']._serialized_end=282
  _globals['_QUERYACCOUNTRESPONSE']._serialized_start=284
  _globals['_QUERYACCOUNTRESPONSE']._serialized_end=357
  _globals['_QUERYCOSMOSACCOUNTREQUEST']._serialized_start=359
  _globals['_QUERYCOSMOSACCOUNTREQUEST']._serialized_end=413
  _globals['_QUERYCOSMOSACCOUNTRESPONSE']._serialized_start=415
  _globals['_QUERYCOSMOSACCOUNTRESPONSE']._serialized_end=509
  _globals['_QUERYVALIDATORACCOUNTREQUEST']._serialized_start=511
  _globals['_QUERYVALIDATORACCOUNTREQUEST']._serialized_end=573
  _globals['_QUERYVALIDATORACCOUNTRESPONSE']._serialized_start=575
  _globals['_QUERYVALIDATORACCOUNTRESPONSE']._serialized_end=673
  _globals['_QUERYBALANCEREQUEST']._serialized_start=675
  _globals['_QUERYBALANCEREQUEST']._serialized_end=723
  _globals['_QUERYBALANCERESPONSE']._serialized_start=725
  _globals['_QUERYBALANCERESPONSE']._serialized_end=764
  _globals['_QUERYSTORAGEREQUEST']._serialized_start=766
  _globals['_QUERYSTORAGEREQUEST']._serialized_end=827
  _globals['_QUERYSTORAGERESPONSE']._serialized_start=829
  _globals['_QUERYSTORAGERESPONSE']._serialized_end=866
  _globals['_QUERYCODEREQUEST']._serialized_start=868
  _globals['_QUERYCODEREQUEST']._serialized_end=913
  _globals['_QUERYCODERESPONSE']._serialized_start=915
  _globals['_QUERYCODERESPONSE']._serialized_end=948
  _globals['_QUERYTXLOGSREQUEST']._serialized_start=950
  _globals['_QUERYTXLOGSREQUEST']._serialized_end=1054
  _globals['_QUERYTXLOGSRESPONSE']._serialized_start=1056
  _globals['_QUERYTXLOGSRESPONSE']._serialized_end=1175
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1177
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1197
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1199
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1268
  _globals['_ETHCALLREQUEST']._serialized_start=1271
  _globals['_ETHCALLREQUEST']._serialized_end=1414
  _globals['_ESTIMATEGASRESPONSE']._serialized_start=1416
  _globals['_ESTIMATEGASRESPONSE']._serialized_end=1450
  _globals['_QUERYTRACETXREQUEST']._serialized_start=1453
  _globals['_QUERYTRACETXREQUEST']._serialized_end=1840
  _globals['_QUERYTRACETXRESPONSE']._serialized_start=1842
  _globals['_QUERYTRACETXRESPONSE']._serialized_end=1878
  _globals['_QUERYTRACEBLOCKREQUEST']._serialized_start=1881
  _globals['_QUERYTRACEBLOCKREQUEST']._serialized_end=2200
  _globals['_QUERYTRACEBLOCKRESPONSE']._serialized_start=2202
  _globals['_QUERYTRACEBLOCKRESPONSE']._serialized_end=2241
  _globals['_QUERYBASEFEEREQUEST']._serialized_start=2243
  _globals['_QUERYBASEFEEREQUEST']._serialized_end=2264
  _globals['_QUERYBASEFEERESPONSE']._serialized_start=2266
  _globals['_QUERYBASEFEERESPONSE']._serialized_end=2350
  _globals['_QUERY']._serialized_start=2353
  _globals['_QUERY']._serialized_end=4000
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/feemarket/v1/feemarket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ethermint/feemarket/v1/feemarket.proto\x12\x16\x65thermint.feemarket.v1\x1a\x14gogoproto/gogo.proto\"\xe5\x02\n\x06Params\x12\x13\n\x0bno_base_fee\x18\x01 \x01(\x08\x12#\n\x1b\x62\x61se_fee_change_denominator\x18\x02 \x01(\r\x12\x1d\n\x15\x65lasticity_multiplier\x18\x03 \x01(\r\x12\x15\n\renable_height\x18\x05 \x01(\x03\x12@\n\x08\x62\x61se_fee\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x45\n\rmin_gas_price\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12J\n\x12min_gas_multiplier\x18\x08 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.DecJ\x04\x08\x04\x10\x05R\x10initial_base_feeB.Z,github.com/evmos/ethermint/x/feemarket/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.feemarket.v1.feemarket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/evmos/ethermint/x/feemarket/types'
  _PARAMS.fields_by_name['base_fee']._options = None
  _PARAMS.fields_by_name['base_fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _PARAMS.fields_by_name['min_gas_price']._options = None
  _PARAMS.fields_by_name['min_gas_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PARAMS.fields_by_name['min_gas_multiplier']._options = None
  _PARAMS.fields_by_name['min_gas_multiplier']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_PARAMS']._serialized_start=89
  _globals['_PARAMS']._serialized_end=446
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/erc20/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.fx.erc20.v1 import erc20_pb2 as fx_dot_erc20_dot_v1_dot_erc20__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x66x/erc20/v1/genesis.proto\x12\x0b\x66x.erc20.v1\x1a\x17\x66x/erc20/v1/erc20.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"l\n\x0cGenesisState\x12)\n\x06params\x18\x01 \x01(\x0b\x32\x13.fx.erc20.v1.ParamsB\x04\xc8\xde\x1f\x00\x12\x31\n\x0btoken_pairs\x18\x02 \x03(\x0b\x32\x16.fx.erc20.v1.TokenPairB\x04\xc8\xde\x1f\x00\"\xcd\x01\n\x06Params\x12-\n\x0c\x65nable_erc20\x18\x01 \x01(\x08\x42\x17\xf2\xde\x1f\x13yaml:\"enable_erc20\"\x12\x44\n\x0f\x65nable_evm_hook\x18\x02 \x01(\x08\x42+\xe2\xde\x1f\rEnableEVMHook\xf2\xde\x1f\x16yaml:\"enable_evm_hook\"\x12N\n\x0bibc_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:\"ibc_timeout\"\x98\xdf\x1f\x01\x42,Z*github.com/functionx/fx-core/x/erc20/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.erc20.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/functionx/fx-core/x/erc20/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['token_pairs']._options = None
  _GENESISSTATE.fields_by_name['token_pairs']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['enable_erc20']._options = None
  _PARAMS.fields_by_name['enable_erc20']._serialized_options = b'\362\336\037\023yaml:\"enable_erc20\"'
  _PARAMS.fields_by_name['enable_evm_hook']._options = None
  _PARAMS.fields_by_name['enable_evm_hook']._serialized_options = b'\342\336\037\rEnableEVMHook\362\336\037\026yaml:\"enable_evm_hook\"'
  _PARAMS.fields_by_name['ibc_timeout']._options = None
  _PARAMS.fields_by_name['ibc_timeout']._serialized_options = b'\310\336\037\000\362\336\037\022yaml:\"ibc_timeout\"\230\337\037\001'
  _globals['_GENESISSTATE']._serialized_start=121
  _globals['_GENESISSTATE']._serialized_end=229
  _globals['_PARAMS']._serialized_start=232
  _globals['_PARAMS']._serialized_end=437
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.crosschain.v1 import tx_pb2 as fx_dot_crosschain_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the state transitions possible within gravity
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BondedOracle = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/BondedOracle',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracle.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracleResponse.FromString,
                )
        self.AddDelegate = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/AddDelegate',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegate.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegateResponse.FromString,
                )
        self.ReDelegate = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/ReDelegate',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegate.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegateResponse.FromString,
                )
        self.EditBridger = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/EditBridger',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridger.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridgerResponse.FromString,
                )
        self.WithdrawReward = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/WithdrawReward',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawReward.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawRewardResponse.FromString,
                )
        self.UnbondedOracle = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/UnbondedOracle',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracle.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracleResponse.FromString,
                )
        self.OracleSetConfirm = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/OracleSetConfirm',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirm.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirmResponse.FromString,
                )
        self.OracleSetUpdateClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/OracleSetUpdateClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaimResponse.FromString,
                )
        self.BridgeTokenClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/BridgeTokenClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaimResponse.FromString,
                )
        self.SendToFxClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/SendToFxClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaimResponse.FromString,
                )
        self.SendToExternal = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/SendToExternal',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternal.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalResponse.FromString,
                )
        self.CancelSendToExternal = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/CancelSendToExternal',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternal.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternalResponse.FromString,
                )
        self.SendToExternalClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/SendToExternalClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaimResponse.FromString,
                )
        self.RequestBatch = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/RequestBatch',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatch.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatchResponse.FromString,
                )
        self.ConfirmBatch = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/ConfirmBatch',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatch.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatchResponse.FromString,
                )
        self.UpdateParams = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/UpdateParams',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                )
        self.IncreaseBridgeFee = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/IncreaseBridgeFee',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFee.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFeeResponse.FromString,
                )
        self.UpdateChainOracles = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/UpdateChainOracles',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOracles.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOraclesResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the state transitions possible within gravity
    """

    def BondedOracle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddDelegate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReDelegate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditBridger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawReward(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbondedOracle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetConfirm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetUpdateClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BridgeTokenClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToFxClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToExternal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelSendToExternal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToExternalClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/crosschain module
        parameters. The authority is hard-coded to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncreaseBridgeFee(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChainOracles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BondedOracle': grpc.unary_unary_rpc_method_handler(
                    servicer.BondedOracle,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracle.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracleResponse.SerializeToString,
            ),
            'AddDelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDelegate,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegate.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegateResponse.SerializeToString,
            ),
            'ReDelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.ReDelegate,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegate.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegateResponse.SerializeToString,
            ),
            'EditBridger': grpc.unary_unary_rpc_method_handler(
                    servicer.EditBridger,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridger.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridgerResponse.SerializeToString,
            ),
            'WithdrawReward': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawReward,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawReward.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawRewardResponse.SerializeToString,
            ),
            'UnbondedOracle': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbondedOracle,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracle.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracleResponse.SerializeToString,
            ),
            'OracleSetConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetConfirm,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirm.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirmResponse.SerializeToString,
            ),
            'OracleSetUpdateClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetUpdateClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaimResponse.SerializeToString,
            ),
            'BridgeTokenClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.BridgeTokenClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaimResponse.SerializeToString,
            ),
            'SendToFxClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToFxClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaimResponse.SerializeToString,
            ),
            'SendToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToExternal,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternal.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalResponse.SerializeToString,
            ),
            'CancelSendToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelSendToExternal,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternal.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternalResponse.SerializeToString,
            ),
            'SendToExternalClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToExternalClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaimResponse.SerializeToString,
            ),
            'RequestBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestBatch,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatch.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatchResponse.SerializeToString,
            ),
            'ConfirmBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmBatch,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatch.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatchResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'IncreaseBridgeFee': grpc.unary_unary_rpc_method_handler(
                    servicer.IncreaseBridgeFee,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFee.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFeeResponse.SerializeToString,
            ),
            'UpdateChainOracles': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChainOracles,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOracles.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOraclesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.gravity.crosschain.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the state transitions possible within gravity
    """

    @staticmethod
    def BondedOracle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/BondedOracle',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracle.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddDelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/AddDelegate',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegate.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReDelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/ReDelegate',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegate.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditBridger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/EditBridger',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridger.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridgerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WithdrawReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/WithdrawReward',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawReward.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawRewardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbondedOracle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/UnbondedOracle',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracle.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/OracleSetConfirm',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirm.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetUpdateClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/OracleSetUpdateClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BridgeTokenClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/BridgeTokenClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToFxClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/SendToFxClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/SendToExternal',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternal.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelSendToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/CancelSendToExternal',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternal.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToExternalClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/SendToExternalClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/RequestBatch',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatch.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/ConfirmBatch',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatch.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/UpdateParams',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncreaseBridgeFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/IncreaseBridgeFee',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFee.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateChainOracles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/UpdateChainOracles',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOracles.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOraclesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import unittest

from fxsdk.coin import parse_coins, parse_coin


class TestCoinCase(unittest.TestCase):
    def test_parse_coins(self):
        coins = parse_coins("1000000cusd,2000000FX")
        self.assertEqual(2, len(coins))
        self.assertEqual("1000000", coins[0].amount)
        self.assertEqual("cusd", coins[0].denom)
        self.assertEqual("2000000", coins[1].amount)
        self.assertEqual("FX", coins[1].denom)

    def test_parse_coin(self):
        coin = parse_coin("1000000cusd")
        self.assertEqual("1000000", coin.amount)
        self.assertEqual("cusd", coin.denom)


if __name__ == '__main__':
    unittest.main()



import unittest

from fxsdk.client.crosschain import CrossChainClient

grpc_cli = CrossChainClient('https://fx-grpc.functionx.io')


class TestCrossChainClientQuery(unittest.TestCase):

    def test_query_channel(self):
        channel = grpc_cli.query_channel('channel-0')
        print(channel)

    def test_query_channels(self):
        channels = grpc_cli.query_channels()
        print(channels)

    def test_get_fee(self):
        fast_fee = grpc_cli.get_fast('ethereum', 'FX')
        print(fast_fee)


if __name__ == '__main__':
    unittest.main()
